@@ -1,10 +1,8 @@
 use totp_rs::{Rfc6238, TOTP};
 
 #[cfg(feature = "otpauth")]
-fn main () {
-    let mut rfc = Rfc6238::with_defaults(
-        "totp-sercret-123"
-    ).unwrap();
+fn main() {
+    let mut rfc = Rfc6238::with_defaults("totp-sercret-123".as_bytes().to_vec()).unwrap();
 
     // optional, set digits, issuer, account_name
     rfc.digits(8).unwrap();
@@ -18,10 +16,8 @@ fn main () {
 }
 
 #[cfg(not(feature = "otpauth"))]
-fn main () {
-    let mut rfc = Rfc6238::with_defaults(
-        "totp-sercret-123"
-    ).unwrap();
+fn main() {
+    let mut rfc = Rfc6238::with_defaults("totp-sercret-123".into()).unwrap();
 
     // optional, set digits, issuer, account_name
     rfc.digits(8).unwrap();
@@ -30,4 +26,4 @@ fn main () {
     let totp = TOTP::from_rfc6238(rfc).unwrap();
     let code = totp.generate_current().unwrap();
     println!("code: {}", code);
-}
\ No newline at end of file
+}
